﻿using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using System.Windows.Forms;

namespace PCSX2_Profile_Manager
{
    public partial class frmConfig : Form
    {
        #region Events
        public frmConfig()
        {
            InitializeComponent();
        }

        private void frmConfig_Load(object sender, EventArgs e)
        {
            /// Here we set the initial values for the textbox and
            /// combobox, loaded directly from config (if available)
            txtPath.Text = Config.PCSX2Exe;
            comboBox1.SelectedIndex = Config.DCAction;
        }
        #endregion
        #region Buttons
        private void btnBrowse_Click(object sender, EventArgs e)
        {
            /// We create a dialog which doesn't support multiselection,
            /// and it must check if the file and its path exist before
            /// returning a valid path. Also, search for EXEcutable files,
            /// since we're searching for the PCSX2 exe, we don't want to 
            /// see other kind of files we aren't searching for.
            OpenFileDialog dlg = new OpenFileDialog();
            dlg.Multiselect = false;
            dlg.CheckFileExists = true;
            dlg.CheckPathExists = true;
            dlg.Filter = "Executable files (*.exe)|*.exe";
            dlg.FilterIndex = 0;
            if (dlg.ShowDialog() == DialogResult.OK)
            {
                /// All good? then we set the textbox's text to the selected
                /// EXEcutable file.
                txtPath.Text = dlg.FileName;
            }
        }

        private void btnOk_Click(object sender, EventArgs e)
        {
            if (txtPath.Text != String.Empty)
            {
                /// Here we look for an "inis" folder in the selected path, just to make sure
                /// it has a valid PCSX2 folder structure.
                DirectoryInfo Dir = new DirectoryInfo(Path.GetDirectoryName(txtPath.Text));
                DirectoryInfo[] Dirs = Dir.GetDirectories();
                foreach (DirectoryInfo dir in Dirs)
                {
                    if (dir.Name.Trim().ToLower() == "inis")
                    {
                        /// Ok, we have an "inis" folder in the selected path. We set the button's 
                        /// dialogResult to OK (for the waiting processes to continue when they receive
                        /// the OK signal) and we set the Config structure values accordingly.
                        btnOk.DialogResult = DialogResult.OK;
                        this.DialogResult = btnOk.DialogResult;
                        Config.PCSX2Exe = txtPath.Text;
                        Config.DCAction = comboBox1.SelectedIndex;
                        Config.Save();
                        return;
                    }
                }
                /// If we reached here it means the condition above didn't run, meaning there was an error.
                MessageBox.Show("This is not a valid PCSX2 path", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
        }
        #endregion
    }
}
